/* ===================================================
 * bootstrap-select.js v0.2
https://github.com/alphacss/bootstrap-tabbed-select
 * ===================================================
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * ========================================================== */
(function($) {
	$.fn.bootstrapTabbedSelect = function(options) {

		//extend default options with those provided.
		var opts = $.extend({}, $.fn.bootstrapTabbedSelect.defaults, options);

		var topLevel='';
		var subLevel='';
		var selectedValue ='';
		var sectionActive = false;
		var selected = '';

		// rewrite the info in the select box 
		$('optgroup',this).each(function(x) { //for each optgroup

			//get section label
			var sectionLabel = $(this).attr('label');
			
			//get section content
			var sectionContent = '';
			$('option',this).each(function(x) {

				//check if an option is selected, and set section active
				if ($(this).attr('selected')) {
					selectedValue = $(this).attr('value');
					sectionActive = true;
				}
				sectionContent += '<a ';
				$(this).attr('selected') ? sectionContent += 'class="tsactive" ' : '';
				sectionContent += 'value="' + $(this).attr('value') + '">' + $(this).text() + '</a>\n';
			});

			sectionActive ? selected = true : false;

			topLevel += '<li';
			sectionActive ? topLevel += ' class="active"' : '';
			topLevel += '><a href="#'+opts.tabbedSelectId+'-optgroup' + x + '" data-toggle="tab">' + sectionLabel + '</a></li>\n';

			subLevel += '<div id="'+opts.tabbedSelectId+'-optgroup' + x + '" class="tab-pane';
			sectionActive ? subLevel += ' active' : '';
			subLevel += '">\n' + sectionContent + '</div>\n';

			sectionActive = false;

		});
		//replacement tabbed select
		var tabbedselect = '<div id="'+opts.tabbedSelectId+'" class="tabbable '+opts.position+' tabbed-select">\n';
		if ( opts.position != "tabs-below") tabbedselect += '<ul class="nav nav-tabs">\n'+topLevel+'</ul>\n';
		tabbedselect += '<div class="tab-content">\n'+subLevel+'</div>\n'
		if ( opts.position == "tabs-below") tabbedselect += '<ul class="nav nav-tabs">\n'+topLevel+'</ul>\n';
		tabbedselect += '</div>\n';
		//add hidden input field with the selected value
		tabbedselect += '<input type="hidden" name="'+opts.inputId+'" id="'+opts.inputId+'" value="'+selectedValue+'" />\n';
		
		//replace the select with the tabbed menu
		this.replaceWith(tabbedselect);
		
		//set first tab and content area active if nothing is selected
		if (selected == false) {
			$('#'+opts.tabbedSelectId+' div.tab-content div:first-child').addClass('active');
			$('#'+opts.tabbedSelectId+' ul.nav-tabs li:first-child').addClass('active');
		}
		
		//set input field value on click
		$('#'+opts.tabbedSelectId+' .tab-content a').click(function () {
			$('#'+opts.tabbedSelectId+' a').removeClass('tsactive');
			$(this).addClass('tsactive');		
			$('input#'+opts.inputId).attr('value', $(this).attr('value'));
		})
	};

	//default settings
	$.fn.bootstrapTabbedSelect.defaults = {
		'position' : 'tabs-left',
		'tabbedSelectId' : 'tabbed-select',
		'inputId'  : 'tabbed-select-input'
	};

})(jQuery);
